<?php
// Version: 1.1.5; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
	
	
	// Color changer
	if(!$context['user']['is_guest'] && isset($_POST['options']['theme_color']))
	{
	   include_once($GLOBALS['sourcedir'] . '/Profile.php');
	   makeThemeChanges($context['user']['id'], $settings['theme_id']);
	   $options['theme_color'] = $_POST['options']['theme_color'];
	}
	elseif ($context['user']['is_guest'])
	{
	   if (isset($_POST['options']['theme_color']))
	   {
		  $_SESSION['theme_color'] = $_POST['options']['theme_color'];
		  $options['theme_color'] = $_SESSION['theme_color'];
	   }
	   elseif (isset($_SESSION['theme_color']))
		  $options['theme_color'] = $_SESSION['theme_color'];
	}

}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';


	// Any color set by user?
	if (isset($options['theme_color']))
		$settings['theme_main_color'] = $options['theme_color'];

	// If not set, or if not allowed to set
	if(!isset($options['theme_color']) || (isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'no'))
	{
		// Defaults.
		$options['theme_color'] = isset($settings['theme_main_color']) ? $settings['theme_main_color'] : '';
		$settings['theme_main_color'] = $options['theme_color'];
	}

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style_' , $settings['theme_main_color'] , '.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>
<script language="JavaScript" type="text/javascript">
function CC_noErrors() {
return true;
}

window.onerror = CC_noErrors;
</script>
</head>
<body>';

echo'
<div id="subheader">
<div class="wrapper">

',template_menu(),'

</div>
</div><br />';

// Body
	echo '<br />
	<div id="bodyarea" style="padding: 12px 50px 4px 50px; background: #fff;">';	
			
					
// Header
echo'
<div id="header-l">
<div id="header-r">
<div id="header">
<div id="headerx">';


echo'<table width="100%" border="0">
  <tr><td>
  <a href="'.$scripturl.'" title="', $context['forum_name'], '"><img src="', $settings['images_url'], '/logo.png" alt="" border="0" /></a>
  </td>';
	

echo'
    <td><div style="float:right;
	margin: 8px 20px 0 0;
	font-size: x-small;
	font-family: verdana, sans-serif;
	color: #FFFFFF;">';
	
	 // Color Change

if(isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'box')
echo '

<form action="', $scripturl, '" method="post" class="smalltext">
<select name="options[theme_color]">

<option value="blue" ',$settings['theme_main_color'] == 'blue' ? 'selected="selected"': '', '>', $txt['blue_'], '</option>

<option value="red" ',$settings['theme_main_color'] == 'red' ? 'selected="selected"': '', '>', $txt['red_'], '</option>

<option value="green" ',$settings['theme_main_color'] == 'green' ? 'selected="selected"': '', '>', $txt['green_'], '</option>

<option value="yellow" ',$settings['theme_main_color'] == 'yellow' ? 'selected="selected"': '', '>', $txt['yellow_'], '</option>

<option value="pink" ',$settings['theme_main_color'] == 'pink' ? 'selected="selected"': '', '>', $txt['pink_'], '</option>

<option value="orange" ',$settings['theme_main_color'] == 'orange' ? 'selected="selected"': '', '>', $txt['orange_'], '</option>

<option value="turquoise" ',$settings['theme_main_color'] == 'turquoise' ? 'selected="selected"': '', '>', $txt['turquoise_'], '</option>

<option value="gray" ',$settings['theme_main_color'] == 'gray' ? 'selected="selected"': '', '>', $txt['gray_'], '</option>

<option value="brown" ',$settings['theme_main_color'] == 'brown' ? 'selected="selected"': '', '>', $txt['brown_'], '</option>

</select>
<input type="submit" name="submit" value="Change" style="width: 11ex;" />
</form>';


if(isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'bars')
echo '
<form action="', $scripturl, '" method="post" class="smalltext">

<input style="background-color: #2BB3EB; color: #2BB3EB; width: 22px; height: 8px; border: 0;" type="submit" value="blue" name="options[theme_color]"/>

<input style="background-color: #EC4040; color: #EC4040; width: 22px; height: 8px; border: 0;" type="submit" value="red" name="options[theme_color]"/>

<input style="background-color: #98C413; color: #98C413; width: 22px; height: 8px; border: 0;" type="submit" value="green" name="options[theme_color]"/>

<input style="background-color: #DCCF00; color: #DCCF00; width: 22px; height: 8px; border: 0;" type="submit" value="yellow" name="options[theme_color]"/>

<input style="background-color: #FF02CC; color: #FF02CC; width: 22px; height: 8px; border: 0;" type="submit" value="pink" name="options[theme_color]"/>

<input style="background-color: #FFD202; color: #FFD202; width: 22px; height: 8px; border: 0;" type="submit" value="orange" name="options[theme_color]"/>

<input style="background-color: #49D6D2; color: #49D6D2; width: 22px; height: 8px; border: 0;" type="submit" value="turquoise" name="options[theme_color]"/>

<input style="background-color: #89928F; color: #89928F; width: 22px; height: 8px; border: 0;" type="submit" value="gray" name="options[theme_color]"/>

<input style="background-color: #813F2A; color: #813F2A; width: 22px; height: 8px; border: 0;" type="submit" value="brown" name="options[theme_color]"/>
</form>';	

	
	echo'<br />
	<form action="', $scripturl, '?action=search2" method="post">
							<input name="search" type="text" onfocus="if(this.value==\'', $txt[182], '\')value=\'\';" onblur="if(this.value==\'\')value=\'', $txt[182], '\';" value="', $txt[182], '" />
					<input type="submit" value="', $txt[182], '" />';
		
							// Search within current topic?
							if (!empty($context['current_topic']))
								echo '
								<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
						
								// If we're on a certain board, limit it to this board ;).
							elseif (!empty($context['current_board']))
								echo '
								<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
						
						echo '
						</form><br />';
	if($context['user']['is_logged'])
		        {
echo'
				<b>', $context['user']['name'] , ', ', $txt['welcome_member'], '</b>';
		        
				// Only tell them about their messages if they can read their messages!
				if ($context['allow_pm'])
					echo '<br /> <a href="', $scripturl, '?action=pm">', $txt['member_personal_message'], '</a> ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'], '.';
				echo'
				<br />
				<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a><br />
					<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a>';
		        }
				 else
		        {
				echo '
					<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
						<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="middletext" ', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>           
								<input name="user" type="text" onfocus="if(this.value==\'', $txt[35], '\')value=\'\';" onblur="if(this.value==\'\')value=\'', $txt[35], '\';" value="', $txt[35], '" />
								<input name="passwrd" type="password" onfocus="if(this.value==\'', $txt[36], '\')value=\'\';" onblur="if(this.value==\'\')value=\'', $txt[36], '\';" value="', $txt[36], '" />
								<input type="submit" value="', $txt[34], '" />
								<input type="hidden" name="cookielength" value="-1" />
						</form>';
		        }



echo'
		
	</div></td>
  </tr>
</table>';	
	
echo'	
</div>	
</div>
</div>
</div>';		
					
// Border
echo'
<div class="border">';

// Body
	echo '
	<div style="padding: 4px 70px 4px 70px; background: #fff;">';	

	

	
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	
echo'</div><br />';

echo'</div>';


	
// Footer
echo'
<div id="footer-l">
<div id="footer-r">
<div id="footer">';

// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
	
<div id="copyright" align="center">
<span class="smalltext">

	', theme_copyright(), '<br />
			Colour Cloud by<a href="http://www.simplemachines.org/community/index.php?action=profile;u=110360" target="_blank" title="">BrKn*</a><br />
			<a href="http://validator.w3.org/check/referer" target="_blank">', $txt['xhtml_'], '</a> | 
			<a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank">', $txt['css_'], '</a><br />

<a href="', $scripturl, '?language=turkish">', $txt['turkish_'], '</a> | 
<a href="', $scripturl, '?language=english">', $txt['english_'], '</a>

</span>	
</div>';	


echo'</div>';
	
echo'
</div>
</div>
</div>';	
	



	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}


	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

	// Show the start of the tab section.
	echo '<div id="nav">
				<ul>';

	// Show the [home] button.
	echo'
					<li><a href="', $scripturl, '">' , $txt[103] , '</a></li>';

	// Show the [help] button.
	echo'
					<li><a href="', $scripturl, '?action=help">' , $txt[119] , '</a></li>';

	// How about the [search] button?
	if ($context['allow_search'])
		echo'
					<li><a href="', $scripturl, '?action=search">' , $txt[182] , '</a></li>';

	// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo'
					<li><a href="', $scripturl, '?action=admin">' , $txt[2] , '</a></li>';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo'
					<li><a href="', $scripturl, '?action=profile">' , $txt[79] , '</a></li>';

	// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
		echo'
					<li><a href="', $scripturl, '?action=pm">' , $txt['pm_short'] , ' ', $context['user']['unread_messages'] > 0 ? '[<strong>'. $context['user']['unread_messages'] . '</strong>]' : '' , '</a></li>';

	// The [calendar]!
	if ($context['allow_calendar'])
		echo'
					<li><a href="', $scripturl, '?action=calendar">' , $txt['calendar24'] , '</a></li>';

	// the [member] list button
	if ($context['allow_memberlist'])
		echo'
					<li><a href="', $scripturl, '?action=mlist">' , $txt[331] , '</a></li>';


	// If the user is a guest, show [login] button.
	if ($context['user']['is_guest'])
		echo'
					<li><a href="', $scripturl, '?action=login">' , $txt[34] , '</a></li>';


	// If the user is a guest, also show [register] button.
	if ($context['user']['is_guest'])
		echo'
					<li><a href="', $scripturl, '?action=register">' , $txt[97] , '</a></li>';


	// Otherwise, they might want to [logout]...
	if ($context['user']['is_logged'])
		echo'
					<li><a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' , $txt[108] , '</a></li>';

	// The end of tab section.
	echo '</ul></div>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '">&nbsp;</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode(' &nbsp;|&nbsp; ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '">&nbsp;</td>';
}

?>